#[non_exhaustive]pub enum SnapshotError {
Encode(String),
Decode(String),
VersionMismatch {
expected: u32,
got: u32,
},
InvalidReference(u32),
RestoreError(String),
}Expand description
Errors that can occur during snapshot save/restore.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Encode(String)
Bincode encoding failed.
Decode(String)
Bincode decoding failed.
VersionMismatch
The snapshot was created with a different format version.
Fields
InvalidReference(u32)
A serialized object reference points outside the object table.
RestoreError(String)
A GC object could not be reconstructed (e.g. unknown TypeDescriptor).