pub enum Graph {
Hline(Hline),
Label(Label),
Line(Line),
LineFill(LineFill),
Box(Box),
Polyline(Polyline),
Table(Table),
}Expand description
A non-series visual primitive (e.g. label/line/box).
Variants
Hline(Hline)
Horizontal line.
Label(Label)
Label.
Line(Line)
Line.
LineFill(LineFill)
Line fill.
Box(Box)
Box.
Polyline(Polyline)
Polyline.
Table(Table)
Table.
Implementations
Sourceimpl Graph
impl Graph
Sourcepub fn as_hline(&self) -> Option<&Hline>
pub fn as_hline(&self) -> Option<&Hline>
Returns the underlying Hline if this graph is a horizontal line.
Sourcepub fn as_label(&self) -> Option<&Label>
pub fn as_label(&self) -> Option<&Label>
Returns the underlying Label if this graph is a label.
Sourcepub fn as_linefill(&self) -> Option<&LineFill>
pub fn as_linefill(&self) -> Option<&LineFill>
Returns the underlying LineFill if this graph is a linefill.
Sourcepub fn as_polyline(&self) -> Option<&Polyline>
pub fn as_polyline(&self) -> Option<&Polyline>
Returns the underlying Polyline if this graph is a polyline.