pub struct Chart { /* private fields */ }Expand description
Collection of visuals produced during script execution.
Access via Instance::chart() after executing
bars. Contains two categories of visual outputs:
- Series graphs — per-bar data like
plot(),bgcolor(),fill(), accessed viaseries_graphs(). - Non-series graphs — point-in-time objects like
label.new(),line.new(),box.new(),table.new(), accessed viagraphs().
Examples
let chart = instance.chart();
println!("Background: {:?}", chart.background_color());
println!("Bar count: {}", chart.series_len());
// Series graphs (plots, fills, bgcolor, etc.)
for (id, sg) in chart.series_graphs() {
if let Some(plot) = sg.as_plot() {
println!("Plot '{:?}': {} values", plot.title, plot.series.len());
}
}
// Non-series graphs (labels, lines, boxes, tables, etc.)
for (id, g) in chart.graphs() {
if let Some(line) = g.as_line() {
println!(
"Line from ({},{}) to ({},{})",
line.x1, line.y1, line.x2, line.y2
);
}
}Implementations
Sourceimpl Chart
impl Chart
Sourcepub fn background_color(&self) -> Option<Color>
pub fn background_color(&self) -> Option<Color>
Returns the configured chart background color.
Sourcepub fn series_graphs(
&self,
) -> impl Iterator<Item = (SeriesGraphId, &SeriesGraph)>
pub fn series_graphs( &self, ) -> impl Iterator<Item = (SeriesGraphId, &SeriesGraph)>
Iterates over all per-series graphs.
Sourcepub fn series_graph(&self, id: SeriesGraphId) -> Option<&SeriesGraph>
pub fn series_graph(&self, id: SeriesGraphId) -> Option<&SeriesGraph>
Returns the per-series graph for the given id.
Sourcepub fn graphs(&self) -> impl Iterator<Item = (GraphId, &Graph)>
pub fn graphs(&self) -> impl Iterator<Item = (GraphId, &Graph)>
Iterates over all non-series graphs.
Sourcepub fn series_len(&self) -> usize
pub fn series_len(&self) -> usize
Returns the number of bars in the chart series.
Sourcepub fn bar_colors(&self) -> &BarColors
pub fn bar_colors(&self) -> &BarColors
Returns the bar color overrides for the chart.
Sourcepub fn filled_orders_on_bar(&self, bar_index: usize) -> &[FilledOrder]
pub fn filled_orders_on_bar(&self, bar_index: usize) -> &[FilledOrder]
Returns the list of filled orders on the given bar_index.
Each fill includes the signal/order id (e.g. entry or exit name), price, and signed quantity. Returns an empty slice if the bar has no fills.